<?php
/**
 * Agent Focused Pro appearance settings.
 *
 * @package Agent Focused Pro
 * @author  Marcy Diaz for Winning Agent
 * @license GPL-2.0-or-later
 * @link    https://www.winningagent.com/
 */

$agentfocused_default_colors = array(
	'accent'    => '#67ddab',
	'secondary' => '#566473',
	'footer'    => '#2c333c',
);

$agentfocused_accent_color = get_theme_mod(
	'agentfocused_accent_color',
	$agentfocused_default_colors['accent']
);

$agentfocused_secondary_color = get_theme_mod(
	'agentfocused_secondary_color',
	$agentfocused_default_colors['secondary']
);

$agentfocused_footer_color = get_theme_mod(
	'agentfocused_footer_color',
	$agentfocused_default_colors['footer']
);

$agentfocused_accent_color_contrast   = agentfocused_color_contrast( $agentfocused_accent_color );
$agentfocused_accent_color_brightness = agentfocused_color_brightness( $agentfocused_accent_color, 35 );

$agentfocused_secondary_color_contrast   = agentfocused_color_contrast( $agentfocused_secondary_color );
$agentfocused_secondary_color_brightness = agentfocused_color_brightness( $agentfocused_secondary_color, 35 );

$agentfocused_footer_color_contrast   = agentfocused_color_contrast( $agentfocused_footer_color );
$agentfocused_footer_color_brightness = agentfocused_color_brightness( $agentfocused_footer_color, 35 );

return array(
	'fonts-url'            => 'https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400italic,700,700italic&display=swap',
	'content-width'        => 1350,
	'accent-color'            => $agentfocused_accent_color,
	'secondary-color'            => $agentfocused_secondary_color,
	'footer-color'            => $agentfocused_footer_color,
	'accent-contrast'         => $agentfocused_accent_color_contrast,
	'secondary-contrast'         => $agentfocused_secondary_color_contrast,
	'footer-contrast'         => $agentfocused_footer_color_contrast,
	'default-colors'       => $agentfocused_default_colors,
	'editor-color-palette' => array(
		array(
			'name'  => __( 'Accent color', 'agentfocused' ), // Called “Accent Color” in the Customizer options.
			'slug'  => 'accent',
			'color' => $agentfocused_accent_color,
		),
		array(
			'name'  => __( 'Secondary color', 'agentfocused' ), // Called “Secondary Color” in the Customizer options.
			'slug'  => 'secondary',
			'color' => $agentfocused_secondary_color,
		),
		array(
			'name'  => __( 'Footer color', 'agentfocused' ), // Called “Footer Color” in the Customizer options.
			'slug'  => 'footer',
			'color' => $agentfocused_footer_color,
		),
		array(
			'name'  => __( 'White', 'agentfocused' ),
			'slug'  => 'white',
			'color' => '#fff',
		),
		array(
			'name'  => __( 'Almost black', 'agentfocused' ),
			'slug'  => 'almost-black',
			'color' => '#111',
		),
	),
	'editor-font-sizes'    => array(
		array(
			'name'      => __( 'Small', 'agentfocused' ),
			'shortName' => __( 'S', 'agentfocused' ),
			'size'      => 12,
			'slug'      => 'small',
		),
		array(
			'name'      => __( 'Normal', 'agentfocused' ),
			'shortName' => __( 'M', 'agentfocused' ),
			'size'      => 16,
			'slug'      => 'normal',
		),
		array(
			'name'      => __( 'Large', 'agentfocused' ),
			'shortName' => __( 'L', 'agentfocused' ),
			'size'      => 24,
			'slug'      => 'large',
		),
		array(
			'name'      => __( 'Larger', 'agentfocused' ),
			'shortName' => __( 'XL', 'agentfocused' ),
			'size'      => 30,
			'slug'      => 'larger',
		),
	),
);
