<?php
/**
 * Customizer additions.
 *
 * @package Agent Focused Pro
 * @author  Marcy Diaz for Winning Agent
 * @subpackage Customizations
 * @license GPL2-0+
 */

add_action( 'customize_register', 'agentfocused_customizer_register' );
/**
 * Register settings and controls with the Customizer.
 *
 * @since 2.2.3
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 */
function agentfocused_customizer_register( $wp_customize ) {

	$appearance = genesis_get_config( 'appearance' );

	// Add front page background image.
	$wp_customize->add_section(
		'agentfocused-image',
		array(
			'title'       => __( 'Front Page Image', 'agentfocused' ),
			'description' => __( 'Use the default image or personalize your site by uploading your own image for the front page 1 widget background.<br /><br />The image for the demo is <strong>1600 x 1000 pixels</strong>.', 'agentfocused' ),
			'priority'    => 35,
		)
	);

	$wp_customize->add_setting(
		'agentfocused-front-image',
		array(
			'default'           => sprintf( '%s/images/front-page-image.jpg', get_stylesheet_directory_uri() ),
			'sanitize_callback' => 'esc_url_raw',
			'type'              => 'option',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'front-background-image',
			array(
				'label'    => __( 'Front Image Upload', 'agentfocused' ),
				'section'  => 'agentfocused-image',
				'settings' => 'agentfocused-front-image',
			)
		)
	);

	// Add accent color.
	$wp_customize->add_setting(
		'agentfocused_accent_color',
		[
			'default'           => $appearance['default-colors']['accent'],
			'sanitize_callback' => 'sanitize_hex_color',
		]
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'agentfocused_accent_color',
			[
				'description' => __( 'Change the default accent color for links, buttons, and front page testimonial.', 'agentfocused' ),
				'label'       => __( 'Accent Color', 'agentfocused' ),
				'section'     => 'colors',
				'settings'    => 'agentfocused_accent_color',
			]
		)
	);

	// Add secondary color.
	$wp_customize->add_setting(
		'agentfocused_secondary_color',
		[
			'default'           => $appearance['default-colors']['secondary'],
			'sanitize_callback' => 'sanitize_hex_color',
		]
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'agentfocused_secondary_color',
			[
				'description' => __( 'Change the default secondary color for header, search bars, featured listings, and footer-widgets.', 'agentfocused' ),
				'label'       => __( 'Secondary Color', 'agentfocused' ),
				'section'     => 'colors',
				'settings'    => 'agentfocused_secondary_color',
			]
		)
	);

	// Add footer color.
	$wp_customize->add_setting(
		'agentfocused_footer_color',
		[
			'default'           => $appearance['default-colors']['footer'],
			'sanitize_callback' => 'sanitize_hex_color',
		]
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'agentfocused_footer_color',
			[
				'description' => __( 'Change the default footer color.', 'agentfocused' ),
				'label'       => __( 'Footer Color', 'agentfocused' ),
				'section'     => 'colors',
				'settings'    => 'agentfocused_footer_color',
			]
		)
	);

	$wp_customize->add_setting(
		'agentfocused_logo_width',
		[
			'default'           => 300,
			'sanitize_callback' => 'absint',
		]
	);

	// Add a control for the logo size.
	$wp_customize->add_control(
		'agentfocused_logo_width',
		[
			'label'       => __( 'Logo Width', 'agentfocused' ),
			'description' => __( 'The maximum width of the logo in pixels.', 'agentfocused' ),
			'priority'    => 9,
			'section'     => 'title_tagline',
			'settings'    => 'agentfocused_logo_width',
			'type'        => 'number',
			'input_attrs' => [
				'min' => 100,
			],
		]
	);
}
