<?php
/**
 * Gutenberg theme support.
 *
 * @package Agent Focused Pro
 * @author  Marcy Diaz for Winning Agent
 * @license GPL-2.0+
 * @link    https://www.winningagent.com/
 */

add_action( 'wp_enqueue_scripts', 'agentfocused_enqueue_gutenberg_frontend_styles' );
/**
 * Enqueues Gutenberg front-end styles.
 *
 * @since 2.7.0
 */
function agentfocused_enqueue_gutenberg_frontend_styles() {

	wp_enqueue_style(
		genesis_get_theme_handle() . '-gutenberg',
		get_stylesheet_directory_uri() . '/lib/gutenberg/front-end.css',
		array( genesis_get_theme_handle() ),
		genesis_get_theme_version()
	);
}

add_action( 'enqueue_block_editor_assets', 'agentfocused_block_editor_styles' );
/**
 * Enqueues Gutenberg admin editor fonts and styles.
 *
 * @since 2.7.0
 */
function agentfocused_block_editor_styles() {

	$appearance = genesis_get_config( 'appearance' );

	wp_enqueue_style(
		genesis_get_theme_handle() . '-gutenberg-fonts',
		$appearance['fonts-url'],
		array(),
		genesis_get_theme_version()
	);
}

// Add support for editor styles.
add_theme_support( 'editor-styles' );

// Enqueue editor styles.
add_editor_style( '/lib/gutenberg/style-editor.css' );

// Adds support for block alignments.
add_theme_support( 'align-wide' );

// Make media embeds responsive.
add_theme_support( 'responsive-embeds' );

$agentfocused_appearance = genesis_get_config( 'appearance' );

add_theme_support(
	'editor-font-sizes',
	$agentfocused_appearance['editor-font-sizes']
);

add_theme_support(
	'editor-color-palette',
	$agentfocused_appearance['editor-color-palette']
);

require_once get_stylesheet_directory() . '/lib/gutenberg/inline-styles.php';

add_action( 'after_setup_theme', 'agentfocused_content_width', 0 );
/**
 * Set content width to match the “wide” Gutenberg block width.
 */
function agentfocused_content_width() {

	$appearance = genesis_get_config( 'appearance' );

	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound -- See https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/924
	// Use "wide" width here - width of front page featured listings.
	$GLOBALS['content_width'] = apply_filters( 'agentfocused_content_width', $appearance['content-width'] );
}
