<?php
/**
 * Adds front-end inline styles for the custom Gutenberg color palette.
 *
 * @package Agent Focused Pro
 * @author  Marcy Diaz for Winning Agent
 * @license GPL-2.0+
 * @link    https://www.winningagent.com/
 */

add_action( 'wp_enqueue_scripts', 'agentfocused_custom_gutenberg_css' );
/**
 * Outputs front-end inline styles based on colors declared in config/appearance.php.
 *
 * @since 2.9.0
 */
function agentfocused_custom_gutenberg_css() {

	$appearance = genesis_get_config( 'appearance' );

	$css = <<<CSS

	/* Adds accent color. */
	.has-accent-color {
		color: {$appearance['accent-color']} !important;
	}

	.has-accent-background-color {
		background-color: {$appearance['accent-color']} !important;
	}

	/* Adds secondary color. */
	.has-secondary-color {
		color: {$appearance['secondary-color']} !important;
	}

	.has-secondary-background-color {
		background-color: {$appearance['secondary-color']} !important;
	}

	/* Adds footer color. */
	.has-footer-color {
		color: {$appearance['footer-color']} !important;
	}

	.has-footer-background-color {
		background-color: {$appearance['footer-color']} !important;
	}

	/* Adds white color. */
	.has-white-color {
		color: #fff !important;
	}

	.has-white-background-color {
		background-color: #fff !important;
	}

	/* Adds almost black color. */
	.has-almost-black-color {
		color: #111 !important;
	}

	.has-almost-black-background-color {
		background-color: #111 !important;
	}

	/* AB Blocks */
	.entry-content .ab-block-post-grid header .ab-block-post-grid-title a:focus,
	.entry-content .ab-block-post-grid header .ab-block-post-grid-title a:hover {
		color: {$appearance['accent-color']} !important;
	}

	.ab-block-post-grid a.ab-text-link {
		color: {$appearance['accent-color']};
	}

CSS;

	wp_add_inline_style( genesis_get_theme_handle() . '-gutenberg', $css );

}

add_action( 'enqueue_block_editor_assets', 'agentfocused_custom_gutenberg_admin_css' );
/**
 * Outputs editor inline styles based on colors declared in config/appearance.php.
 *
 * Note this will appear before the style-editor.css injected by JavaScript,
 * so overrides will need to have higher specificity.
 *
 * @since 2.9.0
 */
function agentfocused_custom_gutenberg_admin_css() {

	$appearance = genesis_get_config( 'appearance' );

	$css = <<<CSS

	.block-editor__container .editor-block-list__block a {
		color: {$appearance['accent-color']};
	}

	.editor-styles-wrapper .ab-block-post-grid header .ab-block-post-grid-title a:hover {
		color: {$appearance['accent-color']};
	}

	.block-editor__container .editor-block-list__block .ab-block-post-grid a {
		color: {$appearance['accent-color']};
	}

CSS;

	wp_add_inline_style( genesis_get_theme_handle() . '-gutenberg-fonts', $css );

}
