<?php
/**
 * Adds the customizer CSS to the front end.
 *
 * @package Agent Focused Pro
 * @author  Marcy Diaz for Winning Agent
 * @subpackage Customizations
 * @license GPL-2.0-or-later
 * @link    https://www.winningagent.com/
 */

add_action( 'wp_enqueue_scripts', 'agentfocused_css' );
/**
 * Checks the settings for the accent color, secondary color, and footer color.
 * If any of these values are set the appropriate CSS is output.
 *
 * @since 2.2.3
 */
function agentfocused_css() {

	$appearance = genesis_get_config( 'appearance' );

	$color_accent = get_theme_mod( 'agentfocused_accent_color', $appearance['default-colors']['accent'] ); // Green #67ddab.

	$color_accent_contrast   = agentfocused_color_contrast( $color_accent );

	$color_secondary = get_theme_mod( 'agentfocused_secondary_color', $appearance['default-colors']['secondary'] ); // Gray #566473.

	$color_secondary_contrast = agentfocused_color_contrast( $color_secondary );

	$color_footer = get_theme_mod( 'agentfocused_footer_color', $appearance['default-colors']['footer'] ); // Footer gray #2c333c.

	$color_footer_contrast = agentfocused_color_contrast( $color_footer );

	$logo = wp_get_attachment_image_src( get_theme_mod( 'custom_logo' ), 'full' );

	if ( $logo ) {
		$logo_height           = absint( $logo[2] );
		$logo_max_width        = get_theme_mod( 'agentfocused_logo_width', 300 );
	}

	$css = '';

	$css .= ( $appearance['default-colors']['accent'] !== $color_accent ) ? sprintf(
		'
		a,
		.add-color,
		.entry-title a:hover,
		.entry-title a:focus,
		.user-profile .agent a:hover.larger,
		.user-profile .agent a:focus.larger,
		.comment-header a:hover,
		.comment-header a:focus,
		.comment-reply a::before,
		.footer-widgets a:hover,
		.footer-widgets a:focus,
		.front-page .contact .icon,
		.menu-toggle:hover,
    	.menu-toggle:focus,
    	.menu-toggle.activated,
    	.menu-toggle:hover::before,
    	.menu-toggle:focus::before,
    	.menu-toggle.activated::before  {
			color: %1$s;
		}

		button,
		input[type="button"],
		input[type="reset"],
		input[type="submit"],
		.button,
		.search-form input[type="submit"],
		.property-search input[type="submit"],
		div.gform_wrapper .gform_footer input[type="submit"],
		.enews-widget input[type="submit"],
		.entry-content div.wpforms-container-full .wpforms-form button[type=submit],
		.wpforms-widget div.wpforms-container-full .wpforms-form button[type=submit],
		.archive-pagination li a:hover,
		.archive-pagination li a:focus,
		.archive-pagination .active a,
		.featured-content .entry-title::after,
		.front-page-6 {
			background-color: %1$s;
			color: %2$s;
		}

		.front-page-6,
		.front-page-6 a,
		.front-page-6 cite {
			color: %2$s;
		}

		button,
		input[type="button"],
		input[type="reset"],
		input[type="submit"],
		.button,
		.search-form input[type="submit"],
		.property-search input[type="submit"],
		div.gform_wrapper .gform_footer input[type="submit"],
		.enews-widget input[type="submit"],
		.entry-content div.wpforms-container-full .wpforms-form button[type=submit],
		.wpforms-widget div.wpforms-container-full .wpforms-form button[type=submit] {
				border-color: %1$s;
		}

		@media only screen and (min-width: 980px) {
			.genesis-nav-menu > .current-menu-item > a,
			.genesis-nav-menu > li > a:focus,
			.genesis-nav-menu > li > a:hover,
			.genesis-nav-menu .sub-menu,
			.nav-secondary .genesis-nav-menu > li.menu-item-has-children > a:focus,
			.nav-secondary .genesis-nav-menu > li.menu-item-has-children > a:hover {
				border-color: %1$s;
			}
		}
		',
		$color_accent,
		$color_accent_contrast
	) : '';

	$css .= ( $appearance['default-colors']['secondary'] !== $color_secondary ) ? sprintf(
		'
		.widget.property-search,
		.widget.IDX_Omnibar_Widget,
		.widget.IDX_Omnibar_Widget_Extra,
		.site-header,
		.archive-pagination li a,
		.footer-widgets {
			background-color: %1$s;
			color: %2$s;
		}

		.site-title a,
		.site-title a:focus,
		.site-title a:hover,
		.site-header .genesis-nav-menu > li > a,
		.genesis-nav-menu a,
		.menu-toggle,
		.menu-toggle::before,
		.sub-menu-toggle,
		.sub-menu-toggle:focus,
		.sub-menu-toggle:hover,
		.sub-menu-toggle.activated,
		.footer-widgets .widget-title,
		.footer-widgets .user-profile,
		.footer-widgets .user-profile .agent a.larger {
			color: %2$s;
		}

		.front-page-3::before {
			background-color: %1$s;
		}

		.sidebar .property-search .widget-title,
		.site-header .genesis-nav-menu > a,
		.front-page-3 .featured-listings .widget-title {
			color: %2$s;
		}
		',
		$color_secondary,
		$color_secondary_contrast
	) : '';

	$css .= ( $appearance['default-colors']['footer'] !== $color_footer ) ? sprintf(
		'
		.site-footer,
		.footer-bottom {
			background-color: %1$s;
			color: %2$s;
		}

		.site-footer .genesis-nav-menu a,
		.site-footer p,
		.site-footer p a {
			color: %2$s;
		}
		',
		$color_footer,
		$color_footer_contrast
	) : '';

	$css .= ( has_custom_logo() && ( 300 !== $logo_max_width ) ) ? sprintf(
		'
		.wp-custom-logo .site-container .title-area {
			max-width: %spx;
		}
		',
		$logo_max_width
	) : '';

	$css .= ( has_custom_logo() && ( $logo_max_width <= 100 ) ) ?
		'
		.wp-custom-logo .site-container .title-area {
			max-width: 100px;
		}
		'
	: '';

	// Place menu below logo and center logo once it gets big.
	$css .= ( has_custom_logo() && ( 600 <= $logo_max_width ) ) ?
		'
		.wp-custom-logo .title-area,
		.wp-custom-logo .menu-toggle,
		.wp-custom-logo .nav-primary {
			float: none;
		}

		.wp-custom-logo .title-area {
			margin: 0 auto;
			padding: 0 30px 10px;
			text-align: center;
		}

		@media only screen and (min-width: 980px) {
			.wp-custom-logo .title-area {
				padding: 0 0 10px;
			}
			
			.wp-custom-logo .nav-primary {
				display: block;
				text-align: center;
				max-width: 100%;
			}

			.wp-custom-logo .nav-primary .sub-menu {
				text-align: left;
			}

			.wp-custom-logo .menu-toggle {
				display: none;
			}
		}
		'
	: '';

	if ( $css ) {
		wp_add_inline_style( genesis_get_theme_handle(), $css );
	}
}
